# Rust API client for openapi

freee人事労務のAPI仕様です。

## 認証について

OAuth2.0を利用します。詳細は[ドキュメントの認証](https://developer.freee.co.jp/docs)パートを参照してください。

## エンドポイント

https://api.freee.co.jp/hr

## 後方互換性ありの変更

freeeでは、APIを改善していくために以下のような変更は後方互換性ありとして通知なく変更を入れることがあります。アプリケーション実装者は以下を踏まえて開発を行ってください。

- 新しいAPIリソース・エンドポイントの追加
- 既存のAPIに対して必須ではない新しいリクエストパラメータの追加
- 既存のAPIレスポンスに対する新しいプロパティの追加
- 既存のAPIレスポンスに対するプロパティの順番の入れ変え
- keyとなっているidやcodeの長さの変更（長くする）

## エラーレスポンス

APIリクエストでエラーが発生した場合は、エラー原因に応じたステータスコードおよびメッセージを返します。

|ステータスコード|原因|
|---|---|
|400|リクエストパラメータが不正|
|401|アクセストークンが無効|
|403|アクセス権限がない|
|404|リソースが存在しない|
|429|リクエスト回数制限を越えた|
|503|システム内で予期しないエラーが発生|

メッセージボディ内の `messages` にはエラー内容を説明する文字列が入ります。

```
{
    \"status_code\": 400,
    \"errors\": [
        {
            \"type\": \"bad_request\",
            \"messages\": [
                \"リクエストの形式が不正です。\"
            ]
        }
    ]
}
```

## API使用制限

APIリクエストは1時間で5000回を上限としています。API使用ステータスはレスポンスヘッダに付与されます。

```
X-Ratelimit-Limit:5000
X-Ratelimit-Remaining:4998
X-Ratelimit-Reset:2018-01-01T12:00:00.000000Z
```

各ヘッダの意味は次のとおりです。

|ヘッダ名|説明|
|---|---|
|X-Ratelimit-Limit|使用回数の上限|
|X-Ratelimit-Remaining|残り使用回数|
|X-Ratelimit-Reset|使用回数がリセットされる時刻|

上記に加え、freeeは一定期間に過度のアクセスを検知した場合、APIアクセスをコントロールする場合があります。
その際のhttp status codeは403となります。制限がかかってから10分程度が過ぎると再度使用することができるようになります。



For more information, please visit [https://support.freee.co.jp/hc/ja/requests/new](https://support.freee.co.jp/hc/ja/requests/new)

## Overview

This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [openapi-spec](https://openapis.org) from a remote server, you can easily generate an API client.

- API version: v2022-02-01
- Package version: v2022-02-01
- Build package: `org.openapitools.codegen.languages.RustClientCodegen`

## Installation

Put the package under your project folder in a directory named `openapi` and add the following to `Cargo.toml` under `[dependencies]`:

```
openapi = { path = "./openapi" }
```

## Documentation for API Endpoints

All URIs are relative to *https://api.freee.co.jp/hr*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**action_approval_requests_monthly_attendance**](docs/DefaultApi.md#action_approval_requests_monthly_attendance) | **POST** /api/v1/approval_requests/monthly_attendances/{id}/actions | 月次勤怠締め申請の承認操作 
*DefaultApi* | [**action_approval_requests_overtime_work**](docs/DefaultApi.md#action_approval_requests_overtime_work) | **POST** /api/v1/approval_requests/overtime_works/{id}/actions | 残業申請の承認操作 
*DefaultApi* | [**action_approval_requests_paid_holiday**](docs/DefaultApi.md#action_approval_requests_paid_holiday) | **POST** /api/v1/approval_requests/paid_holidays/{id}/actions | 有給申請の承認操作 
*DefaultApi* | [**bulk_update_employee_dependent_rules**](docs/DefaultApi.md#bulk_update_employee_dependent_rules) | **PUT** /api/v1/employees/{employee_id}/dependent_rules/bulk_update | 更新 
*DefaultApi* | [**create_approval_requests_monthly_attendance**](docs/DefaultApi.md#create_approval_requests_monthly_attendance) | **POST** /api/v1/approval_requests/monthly_attendances | 月次勤怠締め申請の作成 
*DefaultApi* | [**create_approval_requests_overtime_work**](docs/DefaultApi.md#create_approval_requests_overtime_work) | **POST** /api/v1/approval_requests/overtime_works | 残業申請の作成 
*DefaultApi* | [**create_approval_requests_paid_holiday**](docs/DefaultApi.md#create_approval_requests_paid_holiday) | **POST** /api/v1/approval_requests/paid_holidays | 有給申請の作成 
*DefaultApi* | [**create_employee**](docs/DefaultApi.md#create_employee) | **POST** /api/v1/employees | 作成 
*DefaultApi* | [**create_employee_time_clock**](docs/DefaultApi.md#create_employee_time_clock) | **POST** /api/v1/employees/{employee_id}/time_clocks | 打刻情報の登録 
*DefaultApi* | [**create_group**](docs/DefaultApi.md#create_group) | **POST** /api/v1/groups | 部門情報の作成 
*DefaultApi* | [**create_position**](docs/DefaultApi.md#create_position) | **POST** /api/v1/positions | 役職情報の作成 
*DefaultApi* | [**destroy_approval_requests_monthly_attendance**](docs/DefaultApi.md#destroy_approval_requests_monthly_attendance) | **DELETE** /api/v1/approval_requests/monthly_attendances/{id} | 月次勤怠締め申請の削除 
*DefaultApi* | [**destroy_approval_requests_overtime_work**](docs/DefaultApi.md#destroy_approval_requests_overtime_work) | **DELETE** /api/v1/approval_requests/overtime_works/{id} | 残業申請の削除 
*DefaultApi* | [**destroy_approval_requests_paid_holiday**](docs/DefaultApi.md#destroy_approval_requests_paid_holiday) | **DELETE** /api/v1/approval_requests/paid_holidays/{id} | 有給申請の削除 
*DefaultApi* | [**destroy_employee**](docs/DefaultApi.md#destroy_employee) | **DELETE** /api/v1/employees/{id} | 削除 
*DefaultApi* | [**destroy_employee_work_record**](docs/DefaultApi.md#destroy_employee_work_record) | **DELETE** /api/v1/employees/{employee_id}/work_records/{date} | 削除 
*DefaultApi* | [**destroy_group**](docs/DefaultApi.md#destroy_group) | **DELETE** /api/v1/groups/{id} | 部門情報の削除 
*DefaultApi* | [**destroy_position**](docs/DefaultApi.md#destroy_position) | **DELETE** /api/v1/positions/{id} | 役職情報の削除 
*DefaultApi* | [**get_approval_flow_route**](docs/DefaultApi.md#get_approval_flow_route) | **GET** /api/v1/approval_flow_routes/{id} | 申請経路の取得
*DefaultApi* | [**get_approval_flow_routes**](docs/DefaultApi.md#get_approval_flow_routes) | **GET** /api/v1/approval_flow_routes | 申請経路一覧の取得
*DefaultApi* | [**get_approval_requests_monthly_attendance**](docs/DefaultApi.md#get_approval_requests_monthly_attendance) | **GET** /api/v1/approval_requests/monthly_attendances/{id} | 月次勤怠締め申請の詳細取得 
*DefaultApi* | [**get_approval_requests_monthly_attendances**](docs/DefaultApi.md#get_approval_requests_monthly_attendances) | **GET** /api/v1/approval_requests/monthly_attendances | 月次勤怠締め申請の一覧取得 
*DefaultApi* | [**get_approval_requests_overtime_work**](docs/DefaultApi.md#get_approval_requests_overtime_work) | **GET** /api/v1/approval_requests/overtime_works/{id} | 残業申請の詳細取得 
*DefaultApi* | [**get_approval_requests_overtime_works**](docs/DefaultApi.md#get_approval_requests_overtime_works) | **GET** /api/v1/approval_requests/overtime_works | 残業申請の一覧取得 
*DefaultApi* | [**get_approval_requests_paid_holiday**](docs/DefaultApi.md#get_approval_requests_paid_holiday) | **GET** /api/v1/approval_requests/paid_holidays/{id} | 有給申請の詳細取得 
*DefaultApi* | [**get_approval_requests_paid_holidays**](docs/DefaultApi.md#get_approval_requests_paid_holidays) | **GET** /api/v1/approval_requests/paid_holidays | 有給申請の一覧取得 
*DefaultApi* | [**get_bonuses_employee_payroll_statement**](docs/DefaultApi.md#get_bonuses_employee_payroll_statement) | **GET** /api/v1/bonuses/employee_payroll_statements/{employee_id} | 取得 
*DefaultApi* | [**get_bonuses_employee_payroll_statements**](docs/DefaultApi.md#get_bonuses_employee_payroll_statements) | **GET** /api/v1/bonuses/employee_payroll_statements | 一覧の取得 
*DefaultApi* | [**get_company_employees**](docs/DefaultApi.md#get_company_employees) | **GET** /api/v1/companies/{company_id}/employees | 一覧の取得 
*DefaultApi* | [**get_employee**](docs/DefaultApi.md#get_employee) | **GET** /api/v1/employees/{id} | 取得 
*DefaultApi* | [**get_employee_bank_account_rule**](docs/DefaultApi.md#get_employee_bank_account_rule) | **GET** /api/v1/employees/{employee_id}/bank_account_rule | 取得 
*DefaultApi* | [**get_employee_basic_pay_rule**](docs/DefaultApi.md#get_employee_basic_pay_rule) | **GET** /api/v1/employees/{employee_id}/basic_pay_rule | 取得 
*DefaultApi* | [**get_employee_dependent_rules**](docs/DefaultApi.md#get_employee_dependent_rules) | **GET** /api/v1/employees/{employee_id}/dependent_rules | 取得 
*DefaultApi* | [**get_employee_group_memberships**](docs/DefaultApi.md#get_employee_group_memberships) | **GET** /api/v1/employee_group_memberships | 一覧の取得 
*DefaultApi* | [**get_employee_health_insurance_rule**](docs/DefaultApi.md#get_employee_health_insurance_rule) | **GET** /api/v1/employees/{employee_id}/health_insurance_rule | 取得 
*DefaultApi* | [**get_employee_profile_rule**](docs/DefaultApi.md#get_employee_profile_rule) | **GET** /api/v1/employees/{employee_id}/profile_rule | 取得 
*DefaultApi* | [**get_employee_time_clock**](docs/DefaultApi.md#get_employee_time_clock) | **GET** /api/v1/employees/{employee_id}/time_clocks/{id} | 打刻情報の詳細取得 
*DefaultApi* | [**get_employee_time_clocks**](docs/DefaultApi.md#get_employee_time_clocks) | **GET** /api/v1/employees/{employee_id}/time_clocks | 打刻情報の一覧取得 
*DefaultApi* | [**get_employee_time_clocks_available_types**](docs/DefaultApi.md#get_employee_time_clocks_available_types) | **GET** /api/v1/employees/{employee_id}/time_clocks/available_types | 打刻可能種別の取得 
*DefaultApi* | [**get_employee_welfare_pension_insurance_rule**](docs/DefaultApi.md#get_employee_welfare_pension_insurance_rule) | **GET** /api/v1/employees/{employee_id}/welfare_pension_insurance_rule | 取得 
*DefaultApi* | [**get_employee_work_record**](docs/DefaultApi.md#get_employee_work_record) | **GET** /api/v1/employees/{employee_id}/work_records/{date} | 取得 
*DefaultApi* | [**get_employee_work_record_summary**](docs/DefaultApi.md#get_employee_work_record_summary) | **GET** /api/v1/employees/{employee_id}/work_record_summaries/{year}/{month} | 勤怠情報月次サマリの取得 
*DefaultApi* | [**get_employees**](docs/DefaultApi.md#get_employees) | **GET** /api/v1/employees | 一覧の取得 
*DefaultApi* | [**get_groups**](docs/DefaultApi.md#get_groups) | **GET** /api/v1/groups | 部門情報の一覧取得 
*DefaultApi* | [**get_positions**](docs/DefaultApi.md#get_positions) | **GET** /api/v1/positions | 役職情報の一覧取得 
*DefaultApi* | [**get_salaries_employee_payroll_statement**](docs/DefaultApi.md#get_salaries_employee_payroll_statement) | **GET** /api/v1/salaries/employee_payroll_statements/{employee_id} | 取得 
*DefaultApi* | [**get_salaries_employee_payroll_statements**](docs/DefaultApi.md#get_salaries_employee_payroll_statements) | **GET** /api/v1/salaries/employee_payroll_statements | 一覧の取得 
*DefaultApi* | [**get_users_me**](docs/DefaultApi.md#get_users_me) | **GET** /api/v1/users/me | 取得 
*DefaultApi* | [**update_approval_requests_monthly_attendance**](docs/DefaultApi.md#update_approval_requests_monthly_attendance) | **PUT** /api/v1/approval_requests/monthly_attendances/{id} | 月次勤怠締め申請の更新 
*DefaultApi* | [**update_approval_requests_overtime_work**](docs/DefaultApi.md#update_approval_requests_overtime_work) | **PUT** /api/v1/approval_requests/overtime_works/{id} | 残業申請の更新 
*DefaultApi* | [**update_approval_requests_paid_holiday**](docs/DefaultApi.md#update_approval_requests_paid_holiday) | **PUT** /api/v1/approval_requests/paid_holidays/{id} | 有給申請の更新 
*DefaultApi* | [**update_employee**](docs/DefaultApi.md#update_employee) | **PUT** /api/v1/employees/{id} | 更新 
*DefaultApi* | [**update_employee_bank_account_rule**](docs/DefaultApi.md#update_employee_bank_account_rule) | **PUT** /api/v1/employees/{employee_id}/bank_account_rule | 更新 
*DefaultApi* | [**update_employee_basic_pay_rule**](docs/DefaultApi.md#update_employee_basic_pay_rule) | **PUT** /api/v1/employees/{employee_id}/basic_pay_rule | 更新 
*DefaultApi* | [**update_employee_health_insurance_rule**](docs/DefaultApi.md#update_employee_health_insurance_rule) | **PUT** /api/v1/employees/{employee_id}/health_insurance_rule | 更新 
*DefaultApi* | [**update_employee_profile_rule**](docs/DefaultApi.md#update_employee_profile_rule) | **PUT** /api/v1/employees/{employee_id}/profile_rule | 更新 
*DefaultApi* | [**update_employee_welfare_pension_insurance_rule**](docs/DefaultApi.md#update_employee_welfare_pension_insurance_rule) | **PUT** /api/v1/employees/{employee_id}/welfare_pension_insurance_rule | 更新 
*DefaultApi* | [**update_employee_work_record**](docs/DefaultApi.md#update_employee_work_record) | **PUT** /api/v1/employees/{employee_id}/work_records/{date} | 更新 
*DefaultApi* | [**update_employee_work_record_summary**](docs/DefaultApi.md#update_employee_work_record_summary) | **PUT** /api/v1/employees/{employee_id}/work_record_summaries/{year}/{month} | 勤怠情報月次サマリの更新 
*DefaultApi* | [**update_group**](docs/DefaultApi.md#update_group) | **PUT** /api/v1/groups/{id} | 部門情報の更新 
*DefaultApi* | [**update_position**](docs/DefaultApi.md#update_position) | **PUT** /api/v1/positions/{id} | 役職情報の更新 


## Documentation For Models

 - [AccessDeniedError](docs/AccessDeniedError.md)
 - [ApiV1ApprovalActionRequest](docs/ApiV1ApprovalActionRequest.md)
 - [ApiV1ApprovalFlowLogsParams](docs/ApiV1ApprovalFlowLogsParams.md)
 - [ApiV1ApprovalFlowRouteIndexResponseParams](docs/ApiV1ApprovalFlowRouteIndexResponseParams.md)
 - [ApiV1ApprovalFlowRouteResponse](docs/ApiV1ApprovalFlowRouteResponse.md)
 - [ApiV1ApprovalFlowRouteResponseParams](docs/ApiV1ApprovalFlowRouteResponseParams.md)
 - [ApiV1ApprovalFlowRoutesIndexResponse](docs/ApiV1ApprovalFlowRoutesIndexResponse.md)
 - [ApiV1BonusesEmployeePayrollStatementSerializer](docs/ApiV1BonusesEmployeePayrollStatementSerializer.md)
 - [ApiV1BonusesEmployeePayrollStatementsControllerPeriodShowResponse](docs/ApiV1BonusesEmployeePayrollStatementsControllerPeriodShowResponse.md)
 - [ApiV1BonusesEmployeePayrollStatementsIndexSerializer](docs/ApiV1BonusesEmployeePayrollStatementsIndexSerializer.md)
 - [ApiV1CompaniesEmployeeSerializer](docs/ApiV1CompaniesEmployeeSerializer.md)
 - [ApiV1EmployeeCreateRequestSerializer](docs/ApiV1EmployeeCreateRequestSerializer.md)
 - [ApiV1EmployeeGroupMembershipSerializer](docs/ApiV1EmployeeGroupMembershipSerializer.md)
 - [ApiV1EmployeeGroupMembershipsIndexSerializer](docs/ApiV1EmployeeGroupMembershipsIndexSerializer.md)
 - [ApiV1EmployeePayrollStatementsEmployeeAttendanceItemSerializer](docs/ApiV1EmployeePayrollStatementsEmployeeAttendanceItemSerializer.md)
 - [ApiV1EmployeePayrollStatementsEmployeeOvertimePayItemSerializer](docs/ApiV1EmployeePayrollStatementsEmployeeOvertimePayItemSerializer.md)
 - [ApiV1EmployeePayrollStatementsEmployeePayrollStatementItemSerializer](docs/ApiV1EmployeePayrollStatementsEmployeePayrollStatementItemSerializer.md)
 - [ApiV1EmployeeSerializer](docs/ApiV1EmployeeSerializer.md)
 - [ApiV1EmployeeUpdateRequestSerializer](docs/ApiV1EmployeeUpdateRequestSerializer.md)
 - [ApiV1EmployeesBankAccountRuleSerializer](docs/ApiV1EmployeesBankAccountRuleSerializer.md)
 - [ApiV1EmployeesBankAccountRuleUpdateRequestSerializer](docs/ApiV1EmployeesBankAccountRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesBankAccountRulesControllerPeriodShowResponse](docs/ApiV1EmployeesBankAccountRulesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesBankAccountRulesControllerPeriodUpdateBody](docs/ApiV1EmployeesBankAccountRulesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesBankAccountRulesControllerPeriodUpdateResponse](docs/ApiV1EmployeesBankAccountRulesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesBasicPayRuleSerializer](docs/ApiV1EmployeesBasicPayRuleSerializer.md)
 - [ApiV1EmployeesBasicPayRuleUpdateRequestSerializer](docs/ApiV1EmployeesBasicPayRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesBasicPayRulesControllerPeriodShowResponse](docs/ApiV1EmployeesBasicPayRulesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesBasicPayRulesControllerPeriodUpdateBody](docs/ApiV1EmployeesBasicPayRulesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesBasicPayRulesControllerPeriodUpdateResponse](docs/ApiV1EmployeesBasicPayRulesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesControllerPeriodCreateBody](docs/ApiV1EmployeesControllerPeriodCreateBody.md)
 - [ApiV1EmployeesControllerPeriodCreateResponse](docs/ApiV1EmployeesControllerPeriodCreateResponse.md)
 - [ApiV1EmployeesControllerPeriodShowResponse](docs/ApiV1EmployeesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesControllerPeriodUpdateBody](docs/ApiV1EmployeesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesControllerPeriodUpdateResponse](docs/ApiV1EmployeesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesDependentRuleSerializer](docs/ApiV1EmployeesDependentRuleSerializer.md)
 - [ApiV1EmployeesDependentRuleUpdateRequestSerializer](docs/ApiV1EmployeesDependentRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesDependentRulesControllerPeriodBulkUpdateBody](docs/ApiV1EmployeesDependentRulesControllerPeriodBulkUpdateBody.md)
 - [ApiV1EmployeesDependentRulesControllerPeriodBulkUpdateResponse](docs/ApiV1EmployeesDependentRulesControllerPeriodBulkUpdateResponse.md)
 - [ApiV1EmployeesDependentRulesControllerPeriodIndexResponse](docs/ApiV1EmployeesDependentRulesControllerPeriodIndexResponse.md)
 - [ApiV1EmployeesEmployeeMultiHourlyWageWorkRecordSummarySerializer](docs/ApiV1EmployeesEmployeeMultiHourlyWageWorkRecordSummarySerializer.md)
 - [ApiV1EmployeesHealthInsuranceRuleSerializer](docs/ApiV1EmployeesHealthInsuranceRuleSerializer.md)
 - [ApiV1EmployeesHealthInsuranceRuleUpdateRequestSerializer](docs/ApiV1EmployeesHealthInsuranceRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesHealthInsuranceRulesControllerPeriodShowResponse](docs/ApiV1EmployeesHealthInsuranceRulesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesHealthInsuranceRulesControllerPeriodUpdateBody](docs/ApiV1EmployeesHealthInsuranceRulesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesHealthInsuranceRulesControllerPeriodUpdateResponse](docs/ApiV1EmployeesHealthInsuranceRulesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesIndexSerializer](docs/ApiV1EmployeesIndexSerializer.md)
 - [ApiV1EmployeesProfileRuleSerializer](docs/ApiV1EmployeesProfileRuleSerializer.md)
 - [ApiV1EmployeesProfileRuleUpdateRequestSerializer](docs/ApiV1EmployeesProfileRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesProfileRulesControllerPeriodShowResponse](docs/ApiV1EmployeesProfileRulesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesProfileRulesControllerPeriodUpdateBody](docs/ApiV1EmployeesProfileRulesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesProfileRulesControllerPeriodUpdateResponse](docs/ApiV1EmployeesProfileRulesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesTimeClockSerializer](docs/ApiV1EmployeesTimeClockSerializer.md)
 - [ApiV1EmployeesTimeClocksControllerPeriodAvailableTypesResponse](docs/ApiV1EmployeesTimeClocksControllerPeriodAvailableTypesResponse.md)
 - [ApiV1EmployeesTimeClocksControllerPeriodCreateBody](docs/ApiV1EmployeesTimeClocksControllerPeriodCreateBody.md)
 - [ApiV1EmployeesTimeClocksControllerPeriodCreateResponse](docs/ApiV1EmployeesTimeClocksControllerPeriodCreateResponse.md)
 - [ApiV1EmployeesTimeClocksControllerPeriodShowResponse](docs/ApiV1EmployeesTimeClocksControllerPeriodShowResponse.md)
 - [ApiV1EmployeesWelfarePensionInsuranceRuleSerializer](docs/ApiV1EmployeesWelfarePensionInsuranceRuleSerializer.md)
 - [ApiV1EmployeesWelfarePensionInsuranceRuleUpdateRequestSerializer](docs/ApiV1EmployeesWelfarePensionInsuranceRuleUpdateRequestSerializer.md)
 - [ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodShowResponse](docs/ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodShowResponse.md)
 - [ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodUpdateBody](docs/ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodUpdateResponse](docs/ApiV1EmployeesWelfarePensionInsuranceRulesControllerPeriodUpdateResponse.md)
 - [ApiV1EmployeesWorkRecordSerializer](docs/ApiV1EmployeesWorkRecordSerializer.md)
 - [ApiV1EmployeesWorkRecordSummaryControllerPeriodUpdateBody](docs/ApiV1EmployeesWorkRecordSummaryControllerPeriodUpdateBody.md)
 - [ApiV1EmployeesWorkRecordSummarySerializer](docs/ApiV1EmployeesWorkRecordSummarySerializer.md)
 - [ApiV1EmployeesWorkRecordTimeRangeResponseSerializer](docs/ApiV1EmployeesWorkRecordTimeRangeResponseSerializer.md)
 - [ApiV1EmployeesWorkRecordTimeRangeSerializer](docs/ApiV1EmployeesWorkRecordTimeRangeSerializer.md)
 - [ApiV1EmployeesWorkRecordsControllerPeriodUpdateBody](docs/ApiV1EmployeesWorkRecordsControllerPeriodUpdateBody.md)
 - [ApiV1FlowRouteStepSrializerInner](docs/ApiV1FlowRouteStepSrializerInner.md)
 - [ApiV1GroupCreateRequest](docs/ApiV1GroupCreateRequest.md)
 - [ApiV1GroupCreateRequestParams](docs/ApiV1GroupCreateRequestParams.md)
 - [ApiV1GroupMembershipSerializer](docs/ApiV1GroupMembershipSerializer.md)
 - [ApiV1GroupResponse](docs/ApiV1GroupResponse.md)
 - [ApiV1GroupResponseParams](docs/ApiV1GroupResponseParams.md)
 - [ApiV1GroupUpdateRequest](docs/ApiV1GroupUpdateRequest.md)
 - [ApiV1GroupUpdateRequestParams](docs/ApiV1GroupUpdateRequestParams.md)
 - [ApiV1GroupsIndexResponse](docs/ApiV1GroupsIndexResponse.md)
 - [ApiV1HolidaysAndHoursSerializer](docs/ApiV1HolidaysAndHoursSerializer.md)
 - [ApiV1MonthlyAttendanceCreateRequest](docs/ApiV1MonthlyAttendanceCreateRequest.md)
 - [ApiV1MonthlyAttendanceIndexResponse](docs/ApiV1MonthlyAttendanceIndexResponse.md)
 - [ApiV1MonthlyAttendanceIndexResponseParams](docs/ApiV1MonthlyAttendanceIndexResponseParams.md)
 - [ApiV1MonthlyAttendanceResponse](docs/ApiV1MonthlyAttendanceResponse.md)
 - [ApiV1MonthlyAttendanceResponseParams](docs/ApiV1MonthlyAttendanceResponseParams.md)
 - [ApiV1MonthlyAttendanceUpdateRequest](docs/ApiV1MonthlyAttendanceUpdateRequest.md)
 - [ApiV1OvertimeWorkIndexResponse](docs/ApiV1OvertimeWorkIndexResponse.md)
 - [ApiV1OvertimeWorkIndexResponseParams](docs/ApiV1OvertimeWorkIndexResponseParams.md)
 - [ApiV1OvertimeWorkRequest](docs/ApiV1OvertimeWorkRequest.md)
 - [ApiV1OvertimeWorkResponse](docs/ApiV1OvertimeWorkResponse.md)
 - [ApiV1OvertimeWorkResponseParams](docs/ApiV1OvertimeWorkResponseParams.md)
 - [ApiV1PaidHolidayIndexResponse](docs/ApiV1PaidHolidayIndexResponse.md)
 - [ApiV1PaidHolidayIndexResponseParams](docs/ApiV1PaidHolidayIndexResponseParams.md)
 - [ApiV1PaidHolidayRequest](docs/ApiV1PaidHolidayRequest.md)
 - [ApiV1PaidHolidayResponse](docs/ApiV1PaidHolidayResponse.md)
 - [ApiV1PaidHolidayResponseParams](docs/ApiV1PaidHolidayResponseParams.md)
 - [ApiV1PositionIndexResponse](docs/ApiV1PositionIndexResponse.md)
 - [ApiV1PositionRequest](docs/ApiV1PositionRequest.md)
 - [ApiV1PositionRequestParams](docs/ApiV1PositionRequestParams.md)
 - [ApiV1PositionResponse](docs/ApiV1PositionResponse.md)
 - [ApiV1PositionResponseParams](docs/ApiV1PositionResponseParams.md)
 - [ApiV1SalariesEmployeePayrollStatementSerializer](docs/ApiV1SalariesEmployeePayrollStatementSerializer.md)
 - [ApiV1SalariesEmployeePayrollStatementsControllerPeriodIndexResponse](docs/ApiV1SalariesEmployeePayrollStatementsControllerPeriodIndexResponse.md)
 - [ApiV1SalariesEmployeePayrollStatementsControllerPeriodShowResponse](docs/ApiV1SalariesEmployeePayrollStatementsControllerPeriodShowResponse.md)
 - [ApiV1UsersCompanySerializer](docs/ApiV1UsersCompanySerializer.md)
 - [ApiV1UsersMeSerializer](docs/ApiV1UsersMeSerializer.md)
 - [Error](docs/Error.md)
 - [ErrorErrorsInner](docs/ErrorErrorsInner.md)
 - [ForbiddenError](docs/ForbiddenError.md)
 - [ForbiddenErrorErrorsInner](docs/ForbiddenErrorErrorsInner.md)
 - [InternalServerError](docs/InternalServerError.md)
 - [InternalServerErrorErrorsInner](docs/InternalServerErrorErrorsInner.md)
 - [NotfoundError](docs/NotfoundError.md)
 - [NotfoundErrorErrorsInner](docs/NotfoundErrorErrorsInner.md)
 - [UnauthorizedError](docs/UnauthorizedError.md)


To get access to the crate's generated documentation, use:

```
cargo doc --open
```

## Author



